@@ -40,7 +40,10 @@ class LiveHDSException(HDSException):
             url, "This is a live HDS stream, and they are not supported.")
 
 def hdsparse(options, manifest):
-    data = get_http_data(manifest)
+    error, data = get_http_data(manifest)
+    if error:
+        log.error("Cant get manifest file")
+        return
     streams = {}
     bootstrap = {}
     xml = ET.XML(data)
@@ -87,7 +90,7 @@ class HDS(VideoRetriever):
             antal = readbox(bootstrap, box[0])
         baseurl = self.kwargs["manifest"][0:self.kwargs["manifest"].rfind("/")]
 
-        file_d = output(self.options, self.options.output, "flv")
+        file_d = output(self.options, "flv")
         if hasattr(file_d, "read") is False:
             return
 
@@ -106,7 +109,10 @@ class HDS(VideoRetriever):
             if self.options.output != "-":
                 eta.update(i)
                 progressbar(total, i, ''.join(["ETA: ", str(eta)]))
-            data = get_http_data(url)
+            error, data = get_http_data(url)
+            if error:
+                log.error("Missing segment in playlist")
+                return
             number = decode_f4f(i, data)
             file_d.write(data[number:])
             i += 1
@@ -301,9 +307,9 @@ def readasrtbox(data, pos):
 
 def decode_f4f(fragID, fragData):
     start = fragData.find(b"mdat") + 4
-    if (fragID > 1):
+    if fragID > 1:
         tagLen, = struct.unpack_from(">L", fragData, start)
         tagLen &= 0x00ffffff
-        start  += tagLen + 11 + 4
+        start += tagLen + 11 + 4
     return start
 
