@@ -16,6 +16,7 @@ class Service(object):
     def __init__(self, _url):
         self._url = _url
         self._urldata = None
+        self._error = False
 
     @property
     def url(self):
@@ -23,8 +24,8 @@ class Service(object):
 
     def get_urldata(self):
         if self._urldata is None:
-            self._urldata = get_http_data(self.url)
-        return self._urldata
+            self._error, self._urldata = get_http_data(self.url)
+        return self._error, self._urldata
 
     @classmethod
     def handles(cls, url):
@@ -49,6 +50,13 @@ class Service(object):
     def get_subtitle(self, options):
         pass
 
+    def exclude(self, options):
+        if options.exclude:
+            for i in options.exclude:
+                if i in options.output:
+                    return True
+        return False
+
     # the options parameter is unused, but is part of the
     # interface, so we don't want to remove it. Thus, the
     # pylint ignore.
@@ -80,77 +88,25 @@ class OpenGraphThumbMixin(object):
     Mix this into the service class to grab thumbnail from OpenGraph properties.
     """
     def get_thumbnail(self, options):
-        url = opengraph_get(self.get_urldata(), "image")
+        url = opengraph_get(self.get_urldata()[1], "image")
         if url is None:
             return
         download_thumbnail(options, url)
 
 
-from svtplay_dl.service.aftonbladet import Aftonbladet
-from svtplay_dl.service.bambuser import Bambuser
-from svtplay_dl.service.bigbrother import Bigbrother
-from svtplay_dl.service.dbtv import Dbtv
-from svtplay_dl.service.dr import Dr
-from svtplay_dl.service.expressen import Expressen
-from svtplay_dl.service.hbo import Hbo
-from svtplay_dl.service.justin import Justin
-from svtplay_dl.service.kanal5 import Kanal5
-from svtplay_dl.service.lemonwhale import Lemonwhale
-from svtplay_dl.service.mtvnn import Mtvnn
-from svtplay_dl.service.mtvservices import Mtvservices
-from svtplay_dl.service.nrk import Nrk
-from svtplay_dl.service.oppetarkiv import OppetArkiv
-from svtplay_dl.service.picsearch import Picsearch
-from svtplay_dl.service.qbrick import Qbrick
-from svtplay_dl.service.radioplay import Radioplay
-from svtplay_dl.service.ruv import Ruv
-from svtplay_dl.service.sr import Sr
-from svtplay_dl.service.svtplay import Svtplay
-from svtplay_dl.service.tv4play import Tv4play
-from svtplay_dl.service.urplay import Urplay
-from svtplay_dl.service.vg import Vg
-from svtplay_dl.service.viaplay import Viaplay
-from svtplay_dl.service.vimeo import Vimeo
-
-sites = [
-    Aftonbladet,
-    Bambuser,
-    Bigbrother,
-    Dbtv,
-    Dr,
-    Expressen,
-    Hbo,
-    Justin,
-    Lemonwhale,
-    Kanal5,
-    Mtvservices,
-    Mtvnn,
-    Nrk,
-    Qbrick,
-    Picsearch,
-    Ruv,
-    Radioplay,
-    Sr,
-    Svtplay,
-    OppetArkiv,
-    Tv4play,
-    Urplay,
-    Viaplay,
-    Vimeo,
-    Vg]
-
-
 class Generic(object):
     ''' Videos embed in sites '''
-    def get(self, url):
-        data = get_http_data(url)
-        match = re.search(r"src=\"(http://www.svt.se/wd.*)\" height", data)
+    def get(self, sites, url):
+        error, data = get_http_data(url)
+        if error:
+            return url, None
+        match = re.search(r"src=(\"|\')(http://www.svt.se/wd[^\'\"]+)(\"|\')", data)
         stream = None
         if match:
-            url = match.group(1)
+            url = match.group(2)
             for i in sites:
                 if i.handles(url):
-                    url = url.replace("&amp;", "&")
+                    url = url.replace("&amp;", "&").replace("&#038;", "&")
                     return url, i(url)
 
         match = re.search(r"src=\"(http://player.vimeo.com/video/[0-9]+)\" ", data)
@@ -170,7 +126,7 @@ class Generic(object):
             for i in sites:
                 if i.handles(url):
                     return url, i(url)
-        match = re.search(r'iframe src="(http://tv.aftonbladet[^"]*)"', data)
+        match = re.search(r'src="(http://tv.aftonbladet[^"]*)"', data)
         if match:
             url = match.group(1)
             for i in sites:
@@ -192,7 +148,7 @@ class Generic(object):
 
         return url, stream
 
-def service_handler(url):
+def service_handler(sites, url):
     handler = None
 
     for i in sites:
