@@ -1,7 +1,6 @@
 # ex:ts=4:sw=4:sts=4:et
 # -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
 from __future__ import absolute_import
-import sys
 import re
 import json
 import copy
@@ -19,9 +18,17 @@ class Bambuser(Service, OpenGraphThumbMixin):
         match = re.search(r"v/(\d+)", self.url)
         if not match:
             log.error("Can't find video id in url")
-            sys.exit(2)
+            return
+
+        if self.exclude(options):
+            return
+
         json_url = "http://player-c.api.bambuser.com/getVideo.json?api_key=005f64509e19a868399060af746a00aa&vid=%s" % match.group(1)
-        data = get_http_data(json_url)
+        error, data = get_http_data(json_url)
+        if error:
+            log.error("Can't download video info")
+            return
+
         info = json.loads(data)["result"]
         video = info["url"]
         if video[:4] == "rtmp":
