@@ -3,7 +3,6 @@
 from __future__ import absolute_import
 import re
 import json
-import sys
 import copy
 
 from svtplay_dl.service import Service, OpenGraphThumbMixin
@@ -11,17 +10,28 @@ from svtplay_dl.utils import get_http_data
 from svtplay_dl.fetcher.rtmp import RTMP
 from svtplay_dl.fetcher.hls import HLS, hlsparse
 from svtplay_dl.fetcher.hds import hdsparse
+from svtplay_dl.subtitle import subtitle
 from svtplay_dl.log import log
 
 class Dr(Service, OpenGraphThumbMixin):
     supported_domains = ['dr.dk']
 
     def get(self, options):
-        data = self.get_urldata()
+        error, data = self.get_urldata()
+        if error:
+            log.error("Can't download page.")
+            return
+
+        if self.exclude(options):
+            return
+
         match = re.search(r'resource:[ ]*"([^"]*)",', data)
         if match:
             resource_url = match.group(1)
-            resource_data = get_http_data(resource_url)
+            error, resource_data = get_http_data(resource_url)
+            if error:
+                log.error("Can't get resource data")
+                return
             resource = json.loads(resource_data)
             streams = find_stream(options, resource)
             for i in streams:
@@ -30,11 +40,17 @@ class Dr(Service, OpenGraphThumbMixin):
             match = re.search(r'resource="([^"]*)"', data)
             if not match:
                 log.error("Cant find resource info for this video")
-                sys.exit(2)
+                return
             resource_url = "%s" % match.group(1)
-            resource_data = get_http_data(resource_url)
+            error, resource_data = get_http_data(resource_url)
+            if error:
+                log.error("Can't get resource data")
+                return
             resource = json.loads(resource_data)
 
+            if "SubtitlesList" in resource:
+                suburl = resource["SubtitlesList"][0]["Uri"]
+                yield subtitle(copy.copy(options), "wrst", suburl)
             if "Data" in resource:
                 streams = find_stream(options, resource)
                 for i in streams:
@@ -42,8 +58,7 @@ class Dr(Service, OpenGraphThumbMixin):
             else:
                 for stream in resource['Links']:
                     if stream["Target"] == "HDS":
-                        manifest = "%s?hdcore=2.8.0&g=hejsan" % stream["Uri"]
-                        streams = hdsparse(copy.copy(options), manifest)
+                        streams = hdsparse(copy.copy(options), stream["Uri"])
                         if streams:
                             for n in list(streams.keys()):
                                 yield streams[n]
