@@ -5,22 +5,21 @@
 # pylint: disable=E1103
 
 from __future__ import absolute_import
-import sys
 import re
 import json
 import copy
-import xml.etree.ElementTree as ET
 
-from svtplay_dl.utils.urllib import urlparse, quote
+from svtplay_dl.utils.urllib import urlparse, quote_plus
 from svtplay_dl.service import Service
-from svtplay_dl.utils import get_http_data
+from svtplay_dl.utils import get_http_data, filenamify
 from svtplay_dl.log import log
 from svtplay_dl.fetcher.hls import HLS, hlsparse
-from svtplay_dl.fetcher.http import HTTP
+
 
 class JustinException(Exception):
     pass
 
+
 class JustinUrlException(JustinException):
     """
     Used to indicate an invalid URL for a given media_type. E.g.:
@@ -41,56 +40,62 @@ class Justin(Service):
         r'^(?:(?:[a-z]{2}-)?[a-z]{2}\.)?(www\.)?twitch\.tv$',
         r'^(?:(?:[a-z]{2}-)?[a-z]{2}\.)?(www\.)?justin\.tv$']
 
-    # TODO: verify that this will support Justin as well
     api_base_url = 'https://api.twitch.tv'
     hls_base_url = 'http://usher.justin.tv/api/channel/hls'
 
     def get(self, options):
         urlp = urlparse(self.url)
-        success = False
 
-        for jtv_video_type in [self._get_chapter, self._get_archive,
-                               self._get_channel]:
-            try:
-                jtv_video_type(urlp, options)
-                success = True
-                break
-            except JustinUrlException as e:
-                log.debug(str(e))
+        if self.exclude(options):
+            return
 
-        if not success:
+        match = re.match(r'/(\w+)/([bcv])/(\d+)', urlp.path)
+        if not match:
+            data = self._get_channel(options, urlp)
+        else:
+            if match.group(2) in ["b", "c"]:
+                log.error("This twitch video type is unsupported")
+                return
+            data = self._get_archive(options, match.group(3))
+        try:
+            for i in data:
+                yield i
+        except JustinUrlException as e:
             log.debug(str(e))
-            log.error("This twitch/justin video type is unsupported")
-            sys.exit(2)
+            log.error("This twitch video type is unsupported")
+            return
 
+    def _get_static_video(self, options, videoid):
+        access = self._get_access_token(videoid)
 
-    def _get_static_video(self, vid, options, vidtype):
-        url = "http://api.justin.tv/api/broadcast/by_%s/%s.xml?onsite=true" % (
-            vidtype, vid)
-        data = get_http_data(url)
+        if options.output_auto:
+            info = json.loads(get_http_data("https://api.twitch.tv/kraken/videos/v%s" % videoid)[1])
+            if info["description"]:
+                options.output = "twitch-%s-%s_%s" % (info["channel"]["name"], filenamify(info["title"]), filenamify(info["description"]))
+            else:
+                options.output = "twitch-%s-%s" % (info["channel"]["name"], filenamify(info["title"]))
 
-        xml = ET.XML(data)
-        url = xml.find("archive").find("video_file_url").text
+        if "token" not in access:
+            raise JustinUrlException('video', self.url)
+        nauth = quote_plus(str(access["token"]))
+        authsig = access["sig"]
 
-        yield HTTP(copy.copy(options), url)
+        url = "http://usher.twitch.tv/vod/%s?nauth=%s&nauthsig=%s" % (
+            videoid, nauth, authsig)
 
-    def _get_archive(self, urlp, options):
-        match = re.match(r'/\w+/b/(\d+)', urlp.path)
-        if not match:
-            raise JustinUrlException('video', urlp.geturl())
+        streams = hlsparse(url)
+        if streams:
+            for n in list(streams.keys()):
+                yield HLS(copy.copy(options), streams[n], n)
 
-        self._get_static_video(match.group(1), options, 'archive')
+    def _get_archive(self, options, vid):
+        try:
+            for n in self._get_static_video(options, vid):
+                yield n
+        except JustinUrlException as e:
+            log.error(str(e))
 
-
-    def _get_chapter(self, urlp, options):
-        match = re.match(r'/\w+/c/(\d+)', urlp.path)
-        if not match:
-            raise JustinUrlException('video', urlp.geturl())
-
-        self._get_static_video(match.group(1), options, 'chapter')
-
-
-    def _get_access_token(self, channel):
+    def _get_access_token(self, channel, vtype="vods"):
         """
         Get a Twitch access token. It's a three element dict:
 
@@ -105,8 +110,7 @@ class Justin(Service):
         Both `sig` and `token` should be added to the HLS URI, and the
         token should, of course, be URI encoded.
         """
-        return self._ajax_get('/api/channels/%s/access_token' % channel)
-
+        return self._ajax_get('/api/%s/%s/access_token' % (vtype, channel))
 
     def _ajax_get(self, method):
         url = "%s/%s" % (self.api_base_url, method)
@@ -119,26 +123,27 @@ class Justin(Service):
         # There are references to a api_token in global.js; it's used
         # with the "Twitch-Api-Token" HTTP header. But it doesn't seem
         # to be necessary.
-        payload = get_http_data(url, header={
+        error, payload = get_http_data(url, header={
             'Accept': 'application/vnd.twitchtv.v2+json'
         })
         return json.loads(payload)
 
-
     def _get_hls_url(self, channel):
-        access = self._get_access_token(channel)
+        access = self._get_access_token(channel, "channels")
 
-        query = "token=%s&sig=%s" % (quote(access['token']), access['sig'])
+        query = "token=%s&sig=%s" % (quote_plus(access['token']), access['sig'])
         return "%s/%s.m3u8?%s" % (self.hls_base_url, channel, query)
 
-
-    def _get_channel(self, urlp, options):
+    def _get_channel(self, options, urlp):
         match = re.match(r'/(\w+)', urlp.path)
 
         if not match:
             raise JustinUrlException('channel', urlp.geturl())
 
         channel = match.group(1)
+        if options.output_auto:
+            options.output = "twitch-%s" % channel
+
         hls_url = self._get_hls_url(channel)
         urlp = urlparse(hls_url)
 
