@@ -3,16 +3,16 @@
 from __future__ import absolute_import
 import re
 import json
-import sys
 import copy
 import xml.etree.ElementTree as ET
 
 from svtplay_dl.service import Service, OpenGraphThumbMixin
 from svtplay_dl.utils import get_http_data
+from svtplay_dl.utils.urllib import urljoin
 from svtplay_dl.fetcher.rtmp import RTMP
 from svtplay_dl.fetcher.hls import HLS, hlsparse
 from svtplay_dl.log import log
-from svtplay_dl.subtitle import subtitle_tt
+from svtplay_dl.subtitle import subtitle
 
 class Urplay(Service, OpenGraphThumbMixin):
     supported_domains = ['urplay.se', 'ur.se']
@@ -22,26 +22,36 @@ class Urplay(Service, OpenGraphThumbMixin):
         self.subtitle = None
 
     def get(self, options):
-        match = re.search(r"urPlayer.init\((.*)\);", self.get_urldata())
+        error, data = self.get_urldata()
+        if error:
+            log.error("Can't get the page")
+            return
+        match = re.search(r"urPlayer.init\((.*)\);", data)
         if not match:
             log.error("Can't find json info")
-            sys.exit(2)
+            return
+
+        if self.exclude(options):
+            return
+
         data = match.group(1)
         jsondata = json.loads(data)
-        yield subtitle_tt(jsondata["subtitles"].split(",")[0])
+        if len(jsondata["subtitles"]) > 0:
+            yield subtitle(copy.copy(options), "tt", jsondata["subtitles"][0]["file"].split(",")[0])
         basedomain = jsondata["streaming_config"]["streamer"]["redirect"]
-        http = "http://%s/%s" % (basedomain, jsondata["file_html5"])
+        http = "http://%s/%s" % (basedomain, jsondata["file_http"])
         hd = None
-        if len(jsondata["file_html5_hd"]) > 0:
-            http_hd = "http://%s/%s" % (basedomain, jsondata["file_html5_hd"])
+        if len(jsondata["file_http_hd"]) > 0:
+            http_hd = "http://%s/%s" % (basedomain, jsondata["file_http_hd"])
             hls_hd = "%s%s" % (http_hd, jsondata["streaming_config"]["http_streaming"]["hls_file"])
-            tmp = jsondata["file_html5_hd"]
-            match = re.search(".*(mp[34]:.*$)", tmp)
+            tmp = jsondata["file_http_hd"]
+            match = re.search("(mp[34]:.*$)", tmp)
             path_hd = match.group(1)
             hd = True
         hls = "%s%s" % (http, jsondata["streaming_config"]["http_streaming"]["hls_file"])
         rtmp = "rtmp://%s/%s" % (basedomain, jsondata["streaming_config"]["rtmp"]["application"])
-        path = "mp%s:%s" % (jsondata["file_flash"][-1], jsondata["file_flash"])
+        match = re.search("(mp[34]:.*$)", jsondata["file_rtmp"])
+        path = match.group(1)
         streams = hlsparse(hls)
         for n in list(streams.keys()):
             yield HLS(options, streams[n], n)
@@ -54,13 +64,33 @@ class Urplay(Service, OpenGraphThumbMixin):
             options.other = "-v -a %s -y %s" % (jsondata["streaming_config"]["rtmp"]["application"], path_hd)
             yield RTMP(copy.copy(options), rtmp, "720")
 
+    def scrape_episodes(self, options):
+        res = []
+        for relurl in re.findall(r'<a class="puff tv video"\s+title="[^"]*"\s+href="([^"]*)"',
+                                 self.get_urldata()[1]):
+            res.append(urljoin(self.url, relurl.replace("&amp;", "&")))
+
+        if options.all_last != -1:
+            res = res[-options.all_last:]
+
+        return res
+
     def find_all_episodes(self, options):
         match = re.search(r'<link rel="alternate" type="application/rss\+xml" [^>]*href="([^"]+)"',
-                          self.get_urldata())
+                          self.get_urldata()[1])
         if match is None:
-            log.error("Couldn't retrieve episode list")
-            sys.exit(2)
-        url = "http://urplay.se%s" % match.group(1).replace("&amp;", "&")
-        xml = ET.XML(get_http_data(url))
+            log.info("Couldn't retrieve episode list as rss, trying to scrape")
+            return self.scrape_episodes(options)
 
-        return sorted(x.text for x in xml.findall(".//item/link"))
\ No newline at end of file
+        url = "http://urplay.se%s" % match.group(1).replace("&amp;", "&")
+        xml = ET.XML(get_http_data(url)[1])
+
+        episodes = [x.text for x in xml.findall(".//item/link")]
+        episodes_new = []
+        n = 0
+        for i in episodes:
+            if n == options.all_last:
+                break
+            episodes_new.append(i)
+            n += 1
+        return episodes_new
