@@ -1,7 +1,6 @@
 # ex:ts=4:sw=4:sts=4:et
 # -*- tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil -*-
 from __future__ import absolute_import
-import sys
 import json
 import re
 import copy
@@ -15,12 +14,20 @@ class Vimeo(Service, OpenGraphThumbMixin):
     supported_domains = ['vimeo.com']
 
     def get(self, options):
-        match = re.search("data-config-url=\"(.*)\" data-fallback-url", self.get_urldata())
+        error, data = self.get_urldata()
+        if error:
+            log.error("Can't get the page")
+            return
+
+        if self.exclude(options):
+            return
+
+        match = re.search('data-config-url="([^"]+)" data-fallback-url', data)
         if not match:
-            log.error("Can't find data")
-            sys.exit(4)
+            log.error("Can't find video file for: %s", self.url)
+            return
         player_url = match.group(1).replace("&amp;", "&")
-        player_data = get_http_data(player_url)
+        error, player_data = get_http_data(player_url)
 
         if player_data:
             jsondata = json.loads(player_data)
@@ -29,4 +36,4 @@ class Vimeo(Service, OpenGraphThumbMixin):
                 yield HTTP(copy.copy(options), avail_quality[i]["url"], avail_quality[i]["bitrate"])
         else:
             log.error("Can't find any streams.")
-            sys.exit(2)
\ No newline at end of file
+            return
