@@ -9,7 +9,7 @@ from __future__ import absolute_import
 from svtplay_dl.utils import is_py3
 if is_py3:
     # pylint: disable=E0611
-    from urllib.parse import quote, unquote_plus, quote_plus, urlparse, parse_qs
+    from urllib.parse import quote, unquote_plus, quote_plus, urlparse, parse_qs, urljoin
     from urllib.request import urlopen, Request, build_opener, \
                                HTTPCookieProcessor, HTTPRedirectHandler
     from urllib.error import HTTPError, URLError
@@ -17,7 +17,7 @@ if is_py3:
     from http.cookiejar import CookieJar, Cookie
 else:
     from urllib import addinfourl, quote, unquote_plus, quote_plus
-    from urlparse import urlparse, parse_qs
+    from urlparse import urlparse, parse_qs, urljoin
     from urllib2 import urlopen, Request, HTTPError, URLError, build_opener, \
                         HTTPCookieProcessor, HTTPRedirectHandler
     from cookielib import CookieJar, Cookie
